###############################################################################
###############################################################################
##                        Herramientas.tcl
###############################################################################
###############################################################################
## Includes procedures to implement the commands in the 'Tools' and 'Options'
## menus.
###############################################################################
###############################################################################
## (c) 1999-2000 Andrs Garca Garca. fandom@retemail.es
## Distributed under the terms of the GPL licence v2
###############################################################################
###############################################################################

namespace eval Herramientas {

###############################################################################
# ExtensionsDialog
#    Creates a dialog box to choose file extensions
#
# Parameters:
#    title: title of the dialog box
#
# Side effect:
#    Global variable 'bot' will contain the choosen extensions
#
# Returns:
#    1: if cancelled
###############################################################################
proc ExtensionDialog {title} {
    global labelButtons labelTitles options
    variable done

    set coord(x) [winfo rootx .]
    set coord(y) [winfo rooty .]

    set win [toplevel .extDialog]
    wm title $win $title
#    wm resizable $win 0 0
    wm geometry $win +[expr $coord(x)+100]+[expr $coord(y)+15]

    set marcoExt [frame $win.marcoext]
    set marcoRel [frame $marcoExt.marcoint -bd 2 -relief groove]
    set marcoInt [frame $marcoRel.marcoInt]
    set marcoIzq [frame $marcoInt.marcoIzq]
    set marcoCen [frame $marcoInt.marcoCen]
    set marcoDer [frame $marcoInt.marcoDer]
    set marcoBot [frame $win.marcoBot]

    set izqArr   [frame $marcoIzq.arr]
    set izqCen   [frame $marcoIzq.cen]
    set izqAbj   [frame $marcoIzq.abj]
    set izqBot1  [checkbutton $izqArr.bot1 -variable ::Herramientas::bot(1) \
            -onvalue "jpg" -offvalue "" -text "*.jpg"]
    set izqBot2  [checkbutton $izqCen.bot2 -variable ::Herramientas::bot(2) \
            -onvalue "gif" -offvalue "" -text "*.gif"]
    set izqBot3  [checkbutton $izqAbj.bot3 -variable ::Herramientas::bot(3) \
            -onvalue "ps"  -offvalue "" -text "*.ps"]

    set cenArr   [frame $marcoCen.arr]
    set cenCen   [frame $marcoCen.cen]
    set cenAbj   [frame $marcoCen.abj]
    set cenBot1  [checkbutton $cenArr.bot4 -variable ::Herramientas::bot(4) \
            -onvalue "pdf" -offvalue "" -text "*.pdf"]
    set cenBot2  [checkbutton $cenCen.bot5 -variable ::Herramientas::bot(5) \
            -onvalue "txt" -offvalue "" -text "*.txt"]
    set cenBot3  [checkbutton $cenAbj.bot6 -variable ::Herramientas::bot(6) \
            -onvalue "mov" -offvalue "" -text "*.mov"]

    set derArr   [frame $marcoDer.arr]
    set derCen   [frame $marcoDer.cen]
    set derAbj   [frame $marcoDer.abj]
    set derBot1  [checkbutton $derArr.bot7 -variable ::Herramientas::bot(7) \
            -onvalue "avi" -offvalue "" -text "*.avi"]
    set derBot2  [checkbutton $derCen.bot8 -variable ::Herramientas::bot(8) \
            -onvalue "zip" -offvalue "" -text "*.zip"]
    set derBot3  [checkbutton $derAbj.bot9 -variable ::Herramientas::bot(9) \
            -onvalue "tgz" -offvalue "" -text "*.tgz"]

    if {$title!=$labelTitles(exclude)} {
        foreach {index ext} {1 jpg 2 gif 3 ps 4 pdf 5 txt 6 mov 7 avi 8 zip 9 tgz} {
            set ::Herramientas::bot($index) $ext
        }
    } else {
        foreach {index ext} {1 jpg 2 gif 3 ps 4 pdf 5 txt 6 mov 7 avi 8 zip 9 tgz} {
            if {[regexp "$ext" $options(filter)]} {
                set ::Herramientas::bot($index) $ext
            } else {
                set ::Herramientas::bot($index) ""
            }
        }
    }

    set aceptar  [button $marcoBot.aceptar  -textvariable labelButtons(ok)    \
		-width 8 -command "set ::Herramientas::done 1"]
    set cancelar [button $marcoBot.cancelar -textvariable labelButtons(cancel)\
		-width 8 -command "set ::Herramientas::done 0"]

    bind $win <Escape> "$cancelar invoke"

    pack $marcoExt -ipadx 10 -ipady 5
    pack $marcoRel -ipadx 15 -side bottom
    pack $marcoInt
    pack $marcoIzq -pady 15 -side left
    pack $marcoCen -pady 15 -padx 10 -side left
    pack $marcoDer -pady 15 -side left

    pack $izqArr $izqCen $izqAbj -fill x
    pack $izqBot1 -side left
    pack $izqBot2 -side left
    pack $izqBot3 -side left

    pack $cenArr $cenCen $cenAbj -fill x
    pack $cenBot1 -side left
    pack $cenBot2 -side left
    pack $cenBot3 -side left

    pack $derArr $derCen $derAbj -fill x
    pack $derBot1 -side left
    pack $derBot2 -side left
    pack $derBot3 -side left

    pack $marcoBot -fill x -padx 7
    pack $cancelar $aceptar  -side right -pady 5 -padx 3

    grab $win
    tkwait variable ::Herramientas::done
    grab release $win
    destroy $win
    if {$::Herramientas::done==0} {
        return 1
    }

    return
}

###############################################################################
# PurgeFilesDir
#    Sweeps a directory turning files to size 0
#
# Parameters:
#    dir: directory to be processed
#    purgarCmd: extensions of the files to minimize
###############################################################################
proc PurgeFilesDir {dir purgarCmd} {
    global dirGetleft tcl_platform

    cd $dir
    set archivos ""
    set extList  [concat $purgarCmd ram jpeg zip aiff]
    foreach ext $extList {
        set archivos [concat $archivos [glob -nocomplain *.$ext]]
        set archivos [concat $archivos [glob -nocomplain [string toupper *.$ext]]]
    }

    foreach file $archivos {
        file stat $file estado
        if {$estado(size)!=0} {
            file delete -force $file
            Commands::Touch $file
        }
    }

    set directorios [glob -nocomplain */]

    foreach dir $directorios {
        update
        PurgeFilesDir $dir $purgarCmd
        cd ..
    }
    return
}

###############################################################################
# PurgeFiles
#    The procedures takes care of recursively clean directories of files
#    with certain extensions *.jpg, *.gif, etc.
###############################################################################
proc PurgeFiles {} {
    global labelTitles labelMessages

    if [winfo exists .extDialog] {
        return
    }

    if {[ExtensionDialog $labelTitles(purge)]==1} {
        return
    }

    set dir [Dialogos::SelectDirectory]
    if {![string compare $dir ""]} {
        return
    }

    set dirTmp [pwd]
    for {set i 1;set purgarCmd ""} {$i<10} {incr i} {
        append purgarCmd $::Herramientas::bot($i) " "
    }

    PurgeFilesDir $dir $purgarCmd

    tk_messageBox -title $labelTitles(theEnd) -icon info \
        -message $labelMessages(purged)

    cd $dirTmp

    return
}

###############################################################################
# RestoreOriginalsDir
#    Recursively restores the original files.
#
# Parameter:
#    dir: directory in which it will begin to restore.
###############################################################################
proc RestoreOriginalsDir {dir} {

    cd $dir
    set directorio [glob -nocomplain *.orig]
    foreach fichero $directorio {
        file rename -force $fichero [file root $fichero]
    }

    set directories [glob -nocomplain */]
    foreach dir $directories {
	    RestoreOriginalsDir $dir
        cd ..
    }
    return
}

###############################################################################
# RestoreOriginals
#    Starts the process of restoring the original files downloaded from Web
#    pages.
###############################################################################
proc RestoreOriginals {} {
    global labelTitles labelMessages

    set dir [Dialogos::SelectDirectory]
    if {![string compare $dir ""]} {
        return
    }
    set dirTmp [pwd]
    RestoreOriginalsDir $dir

    tk_messageBox -title $labelTitles(theEnd) -icon info \
            -message $labelMessages(restored)

    cd $dirTmp

    return
}

###############################################################################
# SameProxy
#    Disables or enables the entries for the ftp proxy, depending on
#    the checkbutton
###############################################################################
proc SameProxy {} {
    global options
    variable ip

    for {set i 6} {$i<11} {incr i} {
        if {$options(sameProxy)==1} {
            $ip($i) configure -state disabled
        } else {
            $ip($i) configure -state normal
        }
    }

    return
}

###############################################################################
# ConfProxyControl
#    Takes the action ordered by the user in the proxy dialog.
#
# Parameter
#    action: 'clear' if the user wants to clear the configuration.
#            'accept' if the user accepts it.
###############################################################################
proc ConfProxyControl {action} {
    global options
    variable ip
    variable done

    if {$action=="clear"} {
        for {set i 1} {$i<6} {incr i} {
            $ip($i) delete 0 end
        }
        catch {unset options(httpProxy)}
        catch {unset options(ftpProxy)}
    } else {
        for {set i 1} {$i<11} {incr i} {
            set tmp [$ip($i) get]
            if {$tmp==""} {
                focus $ip($i)
                return
            }
            set dirProxy($i) $tmp
            if {($options(sameProxy)==1)&&($i==5)} break
        }
        set options(httpProxy) "$dirProxy(1).$dirProxy(2).$dirProxy(3).$dirProxy(4):$dirProxy(5)"
        if {$options(sameProxy)==0} {
            set options(ftpProxy) "$dirProxy(6).$dirProxy(7).$dirProxy(8).$dirProxy(9):$dirProxy(10)"
        } else {
            set options(ftpProxy) $options(httpProxy)
        }
        set options(proxy) 1
    }
    SaveConfig
    set done 1

    return
}

###############################################################################
# ConfProxyWindow
#    Creates the window in which the user enters his proxy data.
###############################################################################
proc ConfProxyWindow {} {
    global options labelButtons labelTitles
    variable done
    variable ip
    variable n

    set coord(x) [winfo rootx .]
    set coord(y) [winfo rooty .]

    set proxy [toplevel .proxy]
    wm title $proxy $labelTitles(proxy)
    wm resizable $proxy 0 0
    wm geometry  $proxy +[expr $coord(x)+100]+[expr $coord(y)+50]

    set done 0

    set marcoEx   [frame $proxy.marcoEx]
    set marco     [frame $marcoEx.marco -bd 2 -relief groove]
    set marcoIn   [frame $marco.marcoIn]
    set marcoHttp [frame $marcoIn.marcoHttp]
    set marcoFtp  [frame $marcoIn.marcoFtp]

    set label1 [label $marcoHttp.label -textvariable labelDialogs(http)]
    set ip(1)  [entry $marcoHttp.1 -width 3 -bg white -justify  right]
    set ip(2)  [entry $marcoHttp.2 -width 3 -bg white -justify  right]
    set ip(3)  [entry $marcoHttp.3 -width 3 -bg white -justify  right]
    set ip(4)  [entry $marcoHttp.4 -width 3 -bg white -justify  right]
    set ip(5)  [entry $marcoHttp.5 -width 4 -bg white]
    set punto1 [label $marcoHttp.punto1 -text \n. -width 1]
    set punto2 [label $marcoHttp.punto2 -text \n. -width 1]
    set punto3 [label $marcoHttp.punto3 -text \n. -width 1]
    set colon1 [label $marcoHttp.colon1 -text : -width 2]

    set label2 [label $marcoFtp.label  -textvariable labelDialogs(ftp)]
    set ip(6)  [entry $marcoFtp.6  -width 3 -bg white -justify  right]
    set ip(7)  [entry $marcoFtp.7  -width 3 -bg white -justify  right]
    set ip(8)  [entry $marcoFtp.8  -width 3 -bg white -justify  right]
    set ip(9)  [entry $marcoFtp.9  -width 3 -bg white -justify  right]
    set ip(10) [entry $marcoFtp.10 -width 4 -bg white]
    set punto4 [label $marcoFtp.punto4 -text \n. -width 1]
    set punto5 [label $marcoFtp.punto5 -text \n. -width 1]
    set punto6 [label $marcoFtp.punto6 -text \n. -width 1]
    set colon2 [label $marcoFtp.colon2 -text : -width 2]

    set check  [checkbutton $marcoIn.check -textvariable labelDialogs(sameProxy) \
            -variable options(sameProxy) -command ::Herramientas::SameProxy]

    set botones  [frame  $proxy.botones]
    set borrar   [button $botones.borrar   -textvariable labelButtons(clear) \
            -width 8 -command {::Herramientas::ConfProxyControl clear}]
    set aceptar  [button $botones.aceptar  -textvariable labelButtons(ok)    \
            -width 8 -command {::Herramientas::ConfProxyControl accept}]
    set cancelar [button $botones.cancelar -textvariable labelButtons(cancel)\
            -width 8 -command {set ::Herramientas::done 0}]

    pack $cancelar -side right -padx 9 -pady 5
    pack $aceptar  -side right -pady 5
    pack $borrar   -side right -padx 9
    pack $botones  -side bottom -fill x

    pack $label1 $label2 -side left
    pack $ip(5)  $colon1 $ip(4) $punto3 $ip(3) $punto2 $ip(2) $punto1 $ip(1) -side right
    pack $ip(10) $colon2 $ip(9) $punto6 $ip(8) $punto5 $ip(7) $punto4 $ip(6) -side right
    pack $marcoHttp $marcoFtp $check -fill x
    pack $marcoIn -padx 10 -pady 10
    pack $marco -side bottom
    pack $marcoEx -ipadx 10 -ipady 5

    focus $ip(1)

    bind $proxy <Escape> "$cancelar invoke"
    for {set i 1;set n 2} {$i<11} {incr i;incr n} {
        if {($i!=5)&&($i!=10)} {
            bind $ip($i) <Return>   "focus $ip($n)"
            bind $ip($i) <KP_Enter> "focus $ip($n)"
            bind $ip($i) <Key-Right> {
                %W selection range 0 0
                set indice [%W index insert]
                set final  [%W index end]
                if {$indice==$final} {
                    focus $::Herramientas::ip([expr [winfo name %W] +1])
                }
            }
            bind $ip($i) <KeyRelease> {
                if {("%K"=="Left")||("%K"=="Right")||("%K"=="Tab")} {
                    break
                }
                if {[%W index insert]==3} {
                    focus $::Herramientas::ip([expr [winfo name %W] +1])
                }
            }
            bind $ip($i) <KeyPress> {
                if {[%W index end]==3} {
                    if {("%K"!="Left")&&("%K"!="Right")&&("%K"!="Return")&&("%K"!="Tab")&&("%K"!="Delete")&&("%K"!="BackSpace")} {
                        break
                    }
                }
            }
        } else {
            if {$i==5} {
                bind $ip(5) <Key-Right> {
                    %W selection range 0 0
                    set indice [%W index insert]
                    set final  [%W index end]
                    if {$indice==$final} {
                        focus $::Herramientas::ip(6)
                    }
                }
                bind $ip(5) <KeyRelease> {
                    if {[%W index insert]==4} {
                        focus $::Herramientas::ip(6)
                    }
                }
                bind $ip(5) <Return> "
                    focus $ip(6)
                "
                bind $ip($i) <KP_Enter> "
                    focus $ip(6)
                "
            } else {
                bind $ip($i) <KeyRelease> {
                    if {[%W index insert]==4} {
                        focus .proxy.botones.aceptar
                    }
                }
                bind $ip($i) <Return> "
                    focus $ip(6)
                "
                bind $ip($i) <KP_Enter> "
                    focus $ip(6)
                "
            }
            bind $ip($i) <KeyPress> {
                if {[%W index end]==4} {
                    if {("%K"!="Left")&&("%K"!="Return")&&("%K"!="Tab")&&("%K"!="Delete")&&("%K"!="BackSpace")} {
                        break
                    }
                }
            }
        }
        if {$i!=1} {
            bind $ip($i) <Key-Left> {
                %W selection range 0 0
                if {[%W index insert]==0} {
                    focus $::Herramientas::ip([expr [winfo name %W] -1])
                }
            }
        }
        bind $ip($i) <FocusIn> "$ip($i) selection range 0 end"
    }

    if [info exists options(httpProxy)] {
        regexp {([^\.]+)(?:\.)([^\.]+)(?:\.)([^\.]+)(?:\.)([^\.]+)(?::)(.*)} \
                 $options(httpProxy) nada ip1 ip2 ip3 ip4 ip5
        $ip(1) insert insert $ip1
        $ip(2) insert insert $ip2
        $ip(3) insert insert $ip3
        $ip(4) insert insert $ip4
        $ip(5) insert insert $ip5
    }
    if [info exists options(ftpProxy)] {
        regexp {([^\.]+)(?:\.)([^\.]+)(?:\.)([^\.]+)(?:\.)([^\.]+)(?::)(.*)} \
                 $options(ftpProxy) nada ip6 ip7 ip8 ip9 ip10
        $ip(6)  insert insert $ip6
        $ip(7)  insert insert $ip7
        $ip(8)  insert insert $ip8
        $ip(9)  insert insert $ip9
        $ip(10) insert insert $ip10
    }

    SameProxy

    return
}

###############################################################################
# ConfProxy
#     Allows the user to enter the proxy data
###############################################################################
proc ConfProxy {} {
    global options
    variable ip

    if [winfo exists .proxy] {
        return
    }

    ConfProxyWindow
    tkwait variable ::Herramientas::done

    destroy .proxy

    return
}

###############################################################################
# FilterFiles
#    You can choose which file extensions will be ignored while downloading a
#    Web site.
#
# Side effects:
#    If a filter is chosen the global variable 'options(onlyHtml)' is reset,
#    while 'options(filter)' will contain a regular expression that will be
#    used to filter the links.
###############################################################################
proc FilterFiles {} {
    global options labelTitles labelMessages urlsDownloaded

    if [winfo exists .extDialog] {
        return
    }

    if {[ExtensionDialog $labelTitles(exclude)]==1} {
        return
    }
    catch {unset urlsDownloaded}
    set options(onlyHtml) 0

    for {set i 1;set filter ""} {$i<10} {incr i} {
        if {$::Herramientas::bot($i)!=""} {
            append filter ($::Herramientas::bot($i)$) "|"
        }
    }
    regexp {(.*)(\|)} $filter nada filter

    set options(filter) $filter

    return
}

###############################################################################
# ErrorLog
#    Logs in the file 'Geterror.log' the error messages returned by 'curl'
#
# Parameters
#    link: link that we where trying to download.
#    referer: Referrer page of that link.
###############################################################################
proc ErrorLog {link referer} {
    global dirGetleft getleftState
    global labelDialogs labelMonths supportedLang options
    global errorCode

    set errorLog [file join $dirGetleft(conf) Geterror.log]

    set handle  [open $errorLog a+]
    fconfigure $handle -encoding $supportedLang($options(lang))

    set seconds [clock seconds]
    set month $labelMonths([clock format $seconds -format %B])

    puts $handle "[clock format $seconds -format "%d-$month-%Y -- %H:%M"]"
    puts $handle "$labelDialogs(referer): $referer"
    puts $handle "$labelDialogs(errorLink) $link"

    switch -exact [lindex $errorCode 0] {
        Server {
            puts $handle "$labelDialogs(errorMess) \
                    [lindex $errorCode 2]   [lindex $errorCode 1]"
            if {[lindex $errorCode 2]==550} {
	            puts $handle "$::Ventana::Rizo::meta(server)\n"
		    }		    
        }
        Getleft {
            puts $handle "$labelDialogs(errorMess) [lindex $errorCode 1]"
        }
        CHILDSTATUS {
            puts $handle "$labelDialogs(errorCurl) [lindex $errorCode 2]"
        }
        default {
            if {$::DEBUG==1} {
                puts $handle "Error no registrado: $errorCode"
            }
        }
    }

    puts $handle ""
    close $handle
    set getleftState(errorFound) 1

    return
}

###############################################################################
# EraseErrorLog
#    Deletes the error log.
###############################################################################
proc EraseErrorLog {} {
    global dirGetleft

    set errorLog [file join "$dirGetleft(conf)" Geterror.log]

    file delete $errorLog

    return
}

###############################################################################
# ShowErrorLog
#    In case of error during a download, this procedures show a window with
#    the contents of the error log.
###############################################################################
proc ShowErrorLog {} {
    global dirGetleft
    global labelDialogs labelMonths labelTitles

    set errorLog [file join "$dirGetleft(conf)" Geterror.log]

    if [file exists $errorLog] {
        Ayuda::DefineWindow $labelTitles(errorLog) $errorLog 1
    }
    return
}

###############################################################################
# UpdateFilesDelete
#    Recursively deletes obsolete files.
#
# Parameter:
#    dir: directory in which it will begin to delete
#
# Returns
#    1 if the dir is empty and can be deleted.
###############################################################################
proc UpdateFilesDelete {dir} {
    variable fileExists

    cd $dir
    set directory [glob -nocomplain *]
    set current [pwd]

    foreach file $directory {
        set file [file join $current $file]
        if {![file isdirectory $file]} {
            if [info exists fileExists($file)] continue
            if [info exists fileExists($file.html)] continue
            if {([regexp {\..+\.orig} $file])||\
                ([regexp {\..+\.html} $file])} {
                if [info exists fileExists([file rootname $file])] continue
            }
            file delete $file
        }
    }

    if [catch {glob *}] {
        return 1
    }

    set directories [glob -nocomplain */]
    foreach dir $directories {
	    set returnCode [UpdateFilesDelete $dir]
        cd ..
        if {$returnCode==1} {
            file delete $dir
        }
    }
    return 0
}

###############################################################################
# UpdateFilesProcess
#    Takes care of getting the links in the html pages and storing to verify
#    with the files.
#
# Parameters
#    url of the web site to be updated.
#    level of recursion we are in.
###############################################################################
proc UpdateFilesProcess {url level} {
    global   options filesDone
    variable fileExists

    set fileName [UrlToFile $url]
    if {[info exists filesDone($fileName)]} {
        if {($level>=$filesDone($fileName))||($options(levels)==-1)} {
            return
        }
    }
    set filesDone($fileName) $level

    if {[file exists $fileName.orig]} {
        set fileName $fileName.orig
    }
    set returnCode [HtmlParser::Parsing $fileName $url]
    if {$returnCode==1} {
        if {$::DEBUG==1} {
            tk_messageBox -type ok -icon error -type ok \
                    -message "No se pudo procesar el fichero: $fileName"
        }
        return
    }
    HtmlParser::FilterLinks $url

    for {set i 1;set urlList ""} {$i<$HtmlParser::nLinks} {incr i} {
        if {$HtmlParser::links($i,ok)==1} {
            set fileName [UrlToFile $HtmlParser::links($i,url)]
            set fileExists($fileName) $level
            if {([regexp {\.html?} $fileName])||\
                ([file exists $fileName.html])} {
                lappend urlList $HtmlParser::links($i,url)
            }
        }
    }

    if {($level<$options(levels))||($options(levels)==-1)} {
        foreach url $urlList {
            UpdateFilesProcess $url [incr level]
        }
    }
    return
}

###############################################################################
# UpdateFiles
#    After updating a site, this will through our local copy deleting the 
#    files that are no longer in the site.
#
# Parameters
#    url of the web site to be updated.
#    dir: local directory where it was saved.
###############################################################################
proc UpdateFiles {{url ""} {dir ""}} {
    global options getleftState directories dirGetleft siteUrl

    if [winfo exists .enterUrlWindow] {
        return
    }

    set options(stopPage)                 0
    set options(stopFile)                 0
    set options(pausePage)                0
    set getleftState(filesChosen)         0
    set getleftState(errorFound)          0

    if {$url==""} {
        set comboEntry [EnterUrlWindow]

        tkwait variable done
        set url [$comboEntry get]
        regsub -all {\n} $url {} url
        destroy .enterUrlWindow

        if {($::done==0)||($url=="")} {
            return
        }
    }

    set parsedUrl [HtmlParser::ParseUrl $url]
    if {$parsedUrl!=1} {
        set siteUrl(www)  [lindex $parsedUrl 1]
        set siteUrl(dir)  [lindex $parsedUrl 2]
    } else return

    catch "unset ::filesDone"
    catch "unset ::urlsDownloaded"

    if {$dir==""} {
        set directories(base) [Dialogos::SelectDirectory $dirGetleft(lastDir)]
        if {![string compare $directories(base) ""]} {
            return
        }
    } else {
        set directories(base) $dir
    }
# Empezamoa a procesar
    UpdateFilesProcess $url 0

    set temp [pwd]
    UpdateFilesDelete $directories(base)
    cd $temp

    return
}

###############################################################################
# The following is some code I wrote to autodetect a proxy, it works, but it
# sometimes takes hours doing it so I haven't made it available through the GUI
###############################################################################

proc DummyProc {newSock addr port} {
    variable proxyIp

    regexp {(.*)(\.)} $addr nada myIp

    set proxyIp $myIp.1

    return
}

proc GuessProxyIp {} {
    variable proxyIp

    set serverSocket [socket -server ::Herramientas::DummyProc 11453]

    set channel [socket [info hostname] 11453]

    tkwait variable ::Herramientas::proxyIp

    close $serverSocket

    puts "La direccion: $proxyIp"

    return
}

proc GuessProxyPort {} {
    variable proxyIp
    variable proxyPort

    package require http

    http::config -proxyhost $proxyIp
    for {set i 80} {$i<=10000} {incr i} {
        http::config -proxyport $i
        if {[catch {http::geturl http://freshmeat.net/appindex/1999/07/17/932219913.html} token]} {
            continue
        }
        if {[::http::status $token]=="ok"} {
            regexp {( [0-9][0-9][0-9] )} [::http::code $token] code
            if {$code==200} {
                set proxyPort $i
                break
            }
        }
    }
    if {$i<=1000} {
        tk_messageBox -message "El proxy: es $proxyIp:$proxyPort" -type ok -icon info
    } else {
        tk_messageBox -message "No se encontr el proxy" -type ok -icon info
    }
    package forget http

    return
}

}
